"""
intp
-------------
Simple meta interpolation.
From an ini file with variables, we do interpolation
into another ini file.

This is useful for generating configuration files.

The interpolation format:

```
From:
[section]
name = value
```

We interpolate into:

```
[config]
attribute = {section.name}
```

Resulting in:

```
[config]
attribute = value
```

"""

from setuptools import setup


setup(
    name='intp',
    version='0.1.2',
    url='https://github.com/jjmurre/intp',
    license='BSD',
    author='Jan Murre',
    author_email='jan.murre@catalyz.nl',
    description='Simple meta interpolation',
    long_description=__doc__,
    py_modules=['intp'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
    ],
    entry_points={
        "console_scripts": ['intp=intp:main'],
    },
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)



import sys
from ConfigParser import ConfigParser
from collections import namedtuple


def main():
    args = sys.argv
    if len(args) < 4:
        print("usage: {} <ini with vars> <ini-that-needs-interpolation> <interpolated-ini>".format(args[0]))
        exit(1)
    vars_ini_fn, src_ini_fn, target_ini_fn = sys.argv[1:]
    src_ini = ConfigParser()
    src_ini.read(vars_ini_fn)

    sections = {}
    for section in src_ini.sections():
        items = dict(src_ini.items(section))
        tpt = namedtuple(section, items.keys())
        sections[section] = tpt._make(items.values())

    with open(src_ini_fn) as sf:
        src_ini = sf.read()

    with open(target_ini_fn, 'w') as tf:
        try:
            tf.write(src_ini.format(**sections))
        except AttributeError as e:
            print('Interpolation error: {}'.format(e.message))


if __name__ == '__main__':
    main()
